package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.TShouhuanAlarmList;
import com.ruoyi.system.domain.dto.DataAlarmListDto;

/**
 * 手环报警列信息Service接口
 * 
 * @author ruoyi
 * @date 2023-09-07
 */
public interface ITShouhuanAlarmListService 
{
    /**
     * 查询手环报警列信息
     * 
     * @param id 手环报警列信息主键
     * @return 手环报警列信息
     */
    public TShouhuanAlarmList selectTShouhuanAlarmListById(Integer id);

    /**
     * 查询手环报警列信息列表
     * 
     * @param tShouhuanAlarmList 手环报警列信息
     * @return 手环报警列信息集合
     */
    public List<TShouhuanAlarmList> selectTShouhuanAlarmListList(TShouhuanAlarmList tShouhuanAlarmList);

    /**
     * 查询手环报警列信息列表
     *
     * @param dataAlarmListDto 手环报警列信息
     * @return 手环报警列信息集合
     */
    public List<DataAlarmListDto> selectTShouhuanAlarmList(DataAlarmListDto dataAlarmListDto);

    /**
     * 总数
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmListCount();

    /**
     * 新增手环报警列信息
     * 
     * @param tShouhuanAlarmList 手环报警列信息
     * @return 结果
     */
    public int insertTShouhuanAlarmList(TShouhuanAlarmList tShouhuanAlarmList);

    /**
     * 修改手环报警列信息
     * 
     * @param tShouhuanAlarmList 手环报警列信息
     * @return 结果
     */
    public int updateTShouhuanAlarmList(TShouhuanAlarmList tShouhuanAlarmList);

    /**
     * 批量删除手环报警列信息
     * 
     * @param ids 需要删除的手环报警列信息主键集合
     * @return 结果
     */
    public int deleteTShouhuanAlarmListByIds(Integer[] ids);

    /**
     * 删除手环报警列信息信息
     * 
     * @param id 手环报警列信息主键
     * @return 结果
     */
    public int deleteTShouhuanAlarmListById(Integer id);


    /**
     * SOS总数
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmSOS();

    /**
     * SOS
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmSOSSolve();

    /**
     * 围栏总数
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmRail();

    /**
     * 围栏
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmRailSolve();

    /**
     * 心率总数
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmHeart();

    /**
     * 心率
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmHeartSolve();

    /**
     * 跌倒总数
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmFall();

    /**
     * 跌倒
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmFallSolve();

    /**
     * 低电总数
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmLow();

    /**
     * 低电
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmLowSolve();

    /**
     * 状态在线
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmStatus();

    /**
     * 状态离线
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmStatusSolve();

    /**
     * 其他
     *
     * @return 结果
     */
    public int selectTShouhuanAlarmOtherSolve();
}
